export interface XfTermVO {
  /**
   * 设备Id,主键
   */
  termId: string | number;

  /**
   * 设备机号
   */
  termNo: number;

  /**
   * 设备名称
   */
  termName: string;

  /**
   * 所属餐厅Id
   */
  roomId: string | number;

  /**
   * 结算账户Id
   */
  accountId: string | number;

  /**
   * 设备类型,见XF_TermType字典类型
   */
  termType: string;

  /**
   * 扣费类型,见XF_ConsumeType字典类型
   */
  consumeType: string;

  /**
   * 设备IP
   */
  termIp: string;

  /**
   * 设备通讯端口
   */
  commPort: number;

  /**
   * 备注
   */
  remark: string;
}

export interface XfTermForm extends BaseEntity {
  /**
   * 设备Id,主键
   */
  termId?: string | number;

  /**
   * 设备机号
   */
  termNo?: number;

  /**
   * 设备名称
   */
  termName?: string;

  /**
   * 所属餐厅Id
   */
  roomId?: string | number;

  /**
   * 结算账户Id
   */
  accountId?: string | number;

  /**
   * 设备类型,见XF_TermType字典类型
   */
  termType?: string;

  /**
   * 设备二维码
   */
  qrCode?: string;

  /**
   * 工作站Id
   */
  stationId?: string | number;

  /**
   * 扣费类型,见XF_ConsumeType字典类型
   */
  consumeType?: string;

  /**
   * 是否自动下载参数,见sys_yew_no字典项
   */
  autoDown?: string;

  /**
   * 应用系统,见YYXT数据字典类别
   */
  useType?: string;

  /**
   * 允许使用的卡类
   */
  cardType?: number;

  /**
   * 设备IP
   */
  termIp?: string;

  /**
   * 设备MAC地址
   */
  termMac?: string;

  /**
   * 设备通讯端口
   */
  commPort?: number;

  /**
   * 子网掩码
   */
  mask?: string;

  /**
   * 服务器IP
   */
  serverIp?: string;

  /**
   * 服务器端口
   */
  serverPort?: number;

  /**
   * 网关IP
   */
  gatewayIp?: string;

  /**
   * 心跳间隔,以秒为单位
   */
  beatInterval?: number;

  /**
   * 通讯超时时间,以100毫秒为单位
   */
  timeout?: number;

  /**
   * 允许脱机时间
   */
  offlineTime?: number;

  /**
   * 高级参数
   */
  advParam?: string;

  /**
   * 设备参数
   */
  posParam?: string;

  /**
   * 费率参数
   */
  rateParam?: string;

  /**
   * 消费工作模式,见XF_WorkMode字典类别
   */
  workMode?: string;

  /**
   * 开机模式,0-不需要营业员开机,1-需要营业员开机
   */
  openMode?: string;

  /**
   * 卡上最大金额
   */
  maxCardMoney?: number;

  /**
   * 定值消费金额
   */
  constantValue?: number;

  /**
   * 编号0代表的金额
   */
  rationZero?: number;

  /**
   * 编号1代表的金额
   */
  rationOne?: number;

  /**
   * 编号2代表的金额
   */
  rationTwo?: number;

  /**
   * 编号3代表的金额
   */
  rationThree?: number;

  /**
   * 编号4代表的金额
   */
  rationFour?: number;

  /**
   * 编号5代表的金额
   */
  rationFive?: number;

  /**
   * 编号6代表的金额
   */
  rationSix?: number;

  /**
   * 编号7代表的金额
   */
  rationSeven?: number;

  /**
   * 编号8代表的金额
   */
  rationEight?: number;

  /**
   * 编号9代表的金额
   */
  rationNine?: number;

  /**
   * 每天最大消费次数,0-不限
   */
  dayCount?: number;

  /**
   * 每天最大消费金额
   */
  dayMoney?: number;

  /**
   * 每餐最大消费次数,0-不限
   */
  mealCount?: number;

  /**
   * 单次最大消费金额
   */
  singleMoney?: number;

  /**
   * 早餐消费金额
   */
  breakfastMoney?: number;

  /**
   * 午餐消费金额
   */
  lunchMoney?: number;

  /**
   * 晚餐消费金额
   */
  supperMoney?: number;

  /**
   * 夜宵消费金额
   */
  nightMoney?: number;

  /**
   * 早餐开始时间
   */
  breakfastBegin?: number;

  /**
   * 早餐结束时间
   */
  breakfastEnd?: number;

  /**
   * 午餐开始时间
   */
  lunchBegin?: number;

  /**
   * 午餐结束时间
   */
  lunchEnd?: number;

  /**
   * 晚餐开始时间
   */
  supperBegin?: number;

  /**
   * 晚餐结束时间
   */
  supperEnd?: number;

  /**
   * 宵夜开始时间
   */
  nightBegin?: number;

  /**
   * 宵夜结束时间
   */
  nightEnd?: number;

  /**
   * 两次刷卡间隔,0-不限制
   */
  swipeInterval?: number;

  /**
   * 是否启用卡片有效限制,0-禁用 1-启用
   */
  termValidity?: string | number;

  /**
   * 设备记录流水号
   */
  recordId?: string | number;

  /**
   * 数据上传时间
   */
  uploadTime?: string;

  /**
   * 黑名单下载时间
   */
  blackDownTime?: string;

  /**
   * 最后校时时间
   */
  lastCheck?: string;

  /**
   * 重启时间
   */
  rebootTime?: string;

  /**
   * 备注
   */
  remark?: string;
}

export interface XfTermQuery extends PageQuery {
  /**
   * 设备机号
   */
  termNo?: number;

  /**
   * 设备名称
   */
  termName?: string;

  /**
   * 设备IP
   */
  termIp?: string;

  /**
   * 日期范围参数
   */
  params?: any;
}

export interface XfTermParamVo {
  /**
   * 设备Id,主键
   */
  termId?: string | number;

  /**
   * 设备机号
   */
  termNo?: number;

  /**
   * 设备名称
   */
  termName?: string;

  /**
   * 所属餐厅Id
   */
  roomId?: string | number;

  /**
   * 结算账户Id
   */
  accountId?: string | number;

  /**
   * 设备类型,见XF_TermType字典类型
   */
  termType?: string;

  /**
   * 设备二维码
   */
  qrCode?: string;

  /**
   * 工作站Id
   */
  stationId?: string | number;

  /**
   * 扣费类型,见XF_ConsumeType字典类型
   */
  consumeType?: string;

  /**
   * 是否自动下载参数,见sys_yew_no字典项
   */
  autoDown?: string;

  /**
   * 应用系统,见YYXT数据字典类别
   */
  useType?: string;

  /**
   * 允许使用的卡类
   */
  cardType?: number;

  /**
   * 设备IP
   */
  termIp?: string;

  /**
   * 设备MAC地址
   */
  termMac?: string;

  /**
   * 设备通讯端口
   */
  commPort?: number;

  /**
   * 子网掩码
   */
  mask?: string;

  /**
   * 服务器IP
   */
  serverIp?: string;

  /**
   * 服务器端口
   */
  serverPort?: number;

  /**
   * 网关IP
   */
  gatewayIp?: string;

  /**
   * 心跳间隔,以秒为单位
   */
  beatInterval?: number;

  /**
   * 通讯超时时间,以100毫秒为单位
   */
  timeout?: number;

  /**
   * 允许脱机时间
   */
  offlineTime?: number;

  /**
   * 高级参数
   */
  advParam?: string;

  /**
   * 设备参数
   */
  posParam?: string;

  /**
   * 费率参数
   */
  rateParam?: string;

  /**
   * 消费工作模式,见XF_WorkMode字典类别
   */
  workMode?: string;

  /**
   * 开机模式,0-不需要营业员开机,1-需要营业员开机
   */
  openMode?: string;

  /**
   * 卡上最大金额
   */
  maxCardMoney?: number;

  /**
   * 定值消费金额
   */
  constantValue?: number;

  /**
   * 编号0代表的金额
   */
  rationZero?: number;

  /**
   * 编号1代表的金额
   */
  rationOne?: number;

  /**
   * 编号2代表的金额
   */
  rationTwo?: number;

  /**
   * 编号3代表的金额
   */
  rationThree?: number;

  /**
   * 编号4代表的金额
   */
  rationFour?: number;

  /**
   * 编号5代表的金额
   */
  rationFive?: number;

  /**
   * 编号6代表的金额
   */
  rationSix?: number;

  /**
   * 编号7代表的金额
   */
  rationSeven?: number;

  /**
   * 编号8代表的金额
   */
  rationEight?: number;

  /**
   * 编号9代表的金额
   */
  rationNine?: number;

  /**
   * 每天最大消费次数,0-不限
   */
  dayCount?: number;

  /**
   * 每天最大消费金额
   */
  dayMoney?: number;

  /**
   * 每餐最大消费次数,0-不限
   */
  mealCount?: number;

  /**
   * 单次最大消费金额
   */
  singleMoney?: number;

  /**
   * 早餐消费金额
   */
  breakfastMoney?: number;

  /**
   * 午餐消费金额
   */
  lunchMoney?: number;

  /**
   * 晚餐消费金额
   */
  supperMoney?: number;

  /**
   * 夜宵消费金额
   */
  nightMoney?: number;

  /**
   * 早餐开始时间
   */
  breakfastBegin?: number;

  /**
   * 早餐结束时间
   */
  breakfastEnd?: number;

  /**
   * 午餐开始时间
   */
  lunchBegin?: number;

  /**
   * 午餐结束时间
   */
  lunchEnd?: number;

  /**
   * 晚餐开始时间
   */
  supperBegin?: number;

  /**
   * 晚餐结束时间
   */
  supperEnd?: number;

  /**
   * 宵夜开始时间
   */
  nightBegin?: number;

  /**
   * 宵夜结束时间
   */
  nightEnd?: number;

  /**
   * 两次刷卡间隔,0-不限制
   */
  swipeInterval?: number;

  /**
   * 是否启用卡片有效限制,0-禁用 1-启用
   */
  termValidity?: string | number;

  /**
   * 设备记录流水号
   */
  recordId?: string | number;

  /**
   * 数据上传时间
   */
  uploadTime?: string;

  /**
   * 黑名单下载时间
   */
  blackDownTime?: string;

  /**
   * 最后校时时间
   */
  lastCheck?: string;

  /**
   * 重启时间
   */
  rebootTime?: string;

  /**
   * 备注
   */
  remark?: string;
}

export interface XfTermVOMonitor extends XfTermVO {
  /**
   * 终端状态
   */
  status?: string;
  online?: boolean;
  lastCmdMsg?: string;
  detailMsg?: string;
}
